From 014a36bc1f17904419b5b6c1f3486aca9f5025c7 Mon Sep 17 00:00:00 2001
From: "Dennis B. Troup" <dennis.troup@nist.gov>
Date: Fri, 27 Feb 2015 17:22:12 -0500
Subject: [PATCH] Use /etc/os-release instead of /etc/issue for OS information
 on Linux systems. See
 http://www.freedesktop.org/software/systemd/man/os-release.html

---
 .../java/org/mdpnp/devices/AbstractDevice.java     | 33 +++++++++++++++++-----
 1 file changed, 26 insertions(+), 7 deletions(-)

diff --git a/interop-lab/demo-devices/src/main/java/org/mdpnp/devices/AbstractDevice.java b/interop-lab/demo-devices/src/main/java/org/mdpnp/devices/AbstractDevice.java
index 1833a0a..0cfec90 100644
--- a/interop-lab/demo-devices/src/main/java/org/mdpnp/devices/AbstractDevice.java
+++ b/interop-lab/demo-devices/src/main/java/org/mdpnp/devices/AbstractDevice.java
@@ -31,6 +31,7 @@ import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.management.ManagementFactory;
+import java.nio.charset.Charset;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
@@ -797,18 +798,36 @@ public abstract class AbstractDevice implements ThreadFactory, AbstractDeviceMBe
         
         String osName = System.getProperty("os.name");
         if("Linux".equals(osName)) {
-            Path issue = Paths.get("/etc/issue");
-            File f = issue.toFile();
+        	final String OS_RELEASE_FILE = "/etc/os-release";
+            Path osRelease = Paths.get(OS_RELEASE_FILE);
+            File f = osRelease.toFile();
             if(f.exists() && f.canRead()) {
                 try {
-                    byte[] b = Files.readAllBytes(issue);
-                    osName = new String(b, "ASCII");
-                } catch (IOException e1) {
-                    log.info("Unable to read /etc/issue on this Linux system", e1);
+                    List<String> definitions = Files.readAllLines(osRelease, Charset.forName("UTF-8"));
+					for (String line : definitions) {
+						try {
+							if (line.startsWith("PRETTY_NAME=")) {
+								String value = line.substring(line.indexOf("=") + 1);
+								if (value.startsWith("\"")) { // Remove the quotes around the value.
+									value = value.substring(1, value.length() - 1);
+								}
+								osName = value;
+								break;
+							}
+						} catch (IndexOutOfBoundsException e) {
+							log.debug(e.getMessage());
+						}
+					}
+               } catch (IOException e1) {
+                    log.info("Unable to read " + OS_RELEASE_FILE + " on this Linux system", e1);
                 }
             }
         }
-        deviceIdentity.operating_system = osName + " " + System.getProperty("os.arch") + " " + System.getProperty("os.version");
+        String operatingSystem = osName + " " + System.getProperty("os.arch") + " " + System.getProperty("os.version");
+        if (operatingSystem.length() > 128) {
+        	operatingSystem = operatingSystem.substring(0, 128);
+        }
+        deviceIdentity.operating_system = operatingSystem;
         try {
             iconFromResource(deviceIdentity, iconResourceName());
         } catch (IOException e1) {
-- 
2.2.1.268.g1e6f5b2

